@@ -41,7 +41,7 @@ IPython = pytest.importorskip("IPython")
 io = pytest.importorskip("IPython.utils.io")
 tools = pytest.importorskip("IPython.testing.tools")
 interactiveshell = pytest.importorskip("IPython.terminal.interactiveshell")
-bigquery_storage_v1 = pytest.importorskip("google.cloud.bigquery_storage_v1")
+bigquery_storage = pytest.importorskip("google.cloud.bigquery_storage")
 
 
 @pytest.fixture(scope="session")
@@ -83,8 +83,8 @@ def missing_bq_storage():
 
     def fail_if(name, globals, locals, fromlist, level):
         # NOTE: *very* simplified, assuming a straightforward absolute import
-        return "bigquery_storage_v1" in name or (
-            fromlist is not None and "bigquery_storage_v1" in fromlist
+        return "bigquery_storage" in name or (
+            fromlist is not None and "bigquery_storage" in fromlist
         )
 
     return maybe_fail_import(predicate=fail_if)
@@ -314,14 +314,14 @@ def test__make_bqstorage_client_false():
 
 
 @pytest.mark.skipif(
-    bigquery_storage_v1 is None, reason="Requires `google-cloud-bigquery-storage`"
+    bigquery_storage is None, reason="Requires `google-cloud-bigquery-storage`"
 )
 def test__make_bqstorage_client_true():
     credentials_mock = mock.create_autospec(
         google.auth.credentials.Credentials, instance=True
     )
     got = magics._make_bqstorage_client(True, credentials_mock)
-    assert isinstance(got, bigquery_storage_v1.BigQueryReadClient)
+    assert isinstance(got, bigquery_storage.BigQueryReadClient)
 
 
 def test__make_bqstorage_client_true_raises_import_error(missing_bq_storage):
@@ -338,7 +338,7 @@ def test__make_bqstorage_client_true_raises_import_error(missing_bq_storage):
 
 
 @pytest.mark.skipif(
-    bigquery_storage_v1 is None, reason="Requires `google-cloud-bigquery-storage`"
+    bigquery_storage is None, reason="Requires `google-cloud-bigquery-storage`"
 )
 @pytest.mark.skipif(pandas is None, reason="Requires `pandas`")
 def test__make_bqstorage_client_true_missing_gapic(missing_grpcio_lib):
@@ -396,7 +396,7 @@ def test_extension_load():
 @pytest.mark.usefixtures("ipython_interactive")
 @pytest.mark.skipif(pandas is None, reason="Requires `pandas`")
 @pytest.mark.skipif(
-    bigquery_storage_v1 is None, reason="Requires `google-cloud-bigquery-storage`"
+    bigquery_storage is None, reason="Requires `google-cloud-bigquery-storage`"
 )
 def test_bigquery_magic_without_optional_arguments(monkeypatch):
     ip = IPython.get_ipython()
@@ -410,14 +410,14 @@ def test_bigquery_magic_without_optional_arguments(monkeypatch):
     monkeypatch.setattr(magics.context, "_credentials", mock_credentials)
 
     # Mock out the BigQuery Storage API.
-    bqstorage_mock = mock.create_autospec(bigquery_storage_v1.BigQueryReadClient)
+    bqstorage_mock = mock.create_autospec(bigquery_storage.BigQueryReadClient)
     bqstorage_instance_mock = mock.create_autospec(
-        bigquery_storage_v1.BigQueryReadClient, instance=True
+        bigquery_storage.BigQueryReadClient, instance=True
     )
-    bqstorage_instance_mock.transport = mock.Mock()
+    bqstorage_instance_mock._transport = mock.Mock()
     bqstorage_mock.return_value = bqstorage_instance_mock
     bqstorage_client_patch = mock.patch(
-        "google.cloud.bigquery_storage_v1.BigQueryReadClient", bqstorage_mock
+        "google.cloud.bigquery_storage.BigQueryReadClient", bqstorage_mock
     )
 
     sql = "SELECT 17 AS num"
@@ -559,7 +559,7 @@ def test_bigquery_magic_clears_display_in_verbose_mode():
 
 @pytest.mark.usefixtures("ipython_interactive")
 @pytest.mark.skipif(
-    bigquery_storage_v1 is None, reason="Requires `google-cloud-bigquery-storage`"
+    bigquery_storage is None, reason="Requires `google-cloud-bigquery-storage`"
 )
 def test_bigquery_magic_with_bqstorage_from_argument(monkeypatch):
     ip = IPython.get_ipython()
@@ -573,14 +573,14 @@ def test_bigquery_magic_with_bqstorage_from_argument(monkeypatch):
     monkeypatch.setattr(magics.context, "_credentials", mock_credentials)
 
     # Mock out the BigQuery Storage API.
-    bqstorage_mock = mock.create_autospec(bigquery_storage_v1.BigQueryReadClient)
+    bqstorage_mock = mock.create_autospec(bigquery_storage.BigQueryReadClient)
     bqstorage_instance_mock = mock.create_autospec(
-        bigquery_storage_v1.BigQueryReadClient, instance=True
+        bigquery_storage.BigQueryReadClient, instance=True
     )
-    bqstorage_instance_mock.transport = mock.Mock()
+    bqstorage_instance_mock._transport = mock.Mock()
     bqstorage_mock.return_value = bqstorage_instance_mock
     bqstorage_client_patch = mock.patch(
-        "google.cloud.bigquery_storage_v1.BigQueryReadClient", bqstorage_mock
+        "google.cloud.bigquery_storage.BigQueryReadClient", bqstorage_mock
     )
 
     sql = "SELECT 17 AS num"
@@ -623,7 +623,7 @@ def test_bigquery_magic_with_bqstorage_from_argument(monkeypatch):
 
 @pytest.mark.usefixtures("ipython_interactive")
 @pytest.mark.skipif(
-    bigquery_storage_v1 is None, reason="Requires `google-cloud-bigquery-storage`"
+    bigquery_storage is None, reason="Requires `google-cloud-bigquery-storage`"
 )
 def test_bigquery_magic_with_rest_client_requested(monkeypatch):
     ip = IPython.get_ipython()
@@ -637,9 +637,9 @@ def test_bigquery_magic_with_rest_client_requested(monkeypatch):
     monkeypatch.setattr(magics.context, "_credentials", mock_credentials)
 
     # Mock out the BigQuery Storage API.
-    bqstorage_mock = mock.create_autospec(bigquery_storage_v1.BigQueryReadClient)
+    bqstorage_mock = mock.create_autospec(bigquery_storage.BigQueryReadClient)
     bqstorage_client_patch = mock.patch(
-        "google.cloud.bigquery_storage_v1.BigQueryReadClient", bqstorage_mock
+        "google.cloud.bigquery_storage.BigQueryReadClient", bqstorage_mock
     )
 
     sql = "SELECT 17 AS num"
@@ -841,7 +841,7 @@ def test_bigquery_magic_w_table_id_and_destination_var(ipython_ns_cleanup):
 
 @pytest.mark.usefixtures("ipython_interactive")
 @pytest.mark.skipif(
-    bigquery_storage_v1 is None, reason="Requires `google-cloud-bigquery-storage`"
+    bigquery_storage is None, reason="Requires `google-cloud-bigquery-storage`"
 )
 @pytest.mark.skipif(pandas is None, reason="Requires `pandas`")
 def test_bigquery_magic_w_table_id_and_bqstorage_client():
@@ -864,14 +864,14 @@ def test_bigquery_magic_w_table_id_and_bqstorage_client():
         "google.cloud.bigquery.magics.magics.bigquery.Client", autospec=True
     )
 
-    bqstorage_mock = mock.create_autospec(bigquery_storage_v1.BigQueryReadClient)
+    bqstorage_mock = mock.create_autospec(bigquery_storage.BigQueryReadClient)
     bqstorage_instance_mock = mock.create_autospec(
-        bigquery_storage_v1.BigQueryReadClient, instance=True
+        bigquery_storage.BigQueryReadClient, instance=True
     )
-    bqstorage_instance_mock.transport = mock.Mock()
+    bqstorage_instance_mock._transport = mock.Mock()
     bqstorage_mock.return_value = bqstorage_instance_mock
     bqstorage_client_patch = mock.patch(
-        "google.cloud.bigquery_storage_v1.BigQueryReadClient", bqstorage_mock
+        "google.cloud.bigquery_storage.BigQueryReadClient", bqstorage_mock
     )
 
     table_id = "bigquery-public-data.samples.shakespeare"
